@@ -7,7 +7,10 @@ from django.views.decorators.http import require_http_methods
 from django.views.decorators.csrf import ensure_csrf_cookie, csrf_exempt
 
 from collections import defaultdict
-import json
+try:
+    import ujson as json
+except ImportError:
+    import json
 
 from . import http
 
@@ -15,7 +18,9 @@ def accepts(*verbs):
     '''Annotate a method with the HTTP verbs it accepts, and enforce it.'''
     def _inner(method):
         setattr(method, '_accepts', verbs)
-        return method_decorator(require_http_methods([x.upper() for x in verbs]))(method)
+        return method_decorator(
+            require_http_methods([x.upper() for x in verbs])
+        )(method)
     return _inner
 
 class BasePublisher(object):
@@ -97,14 +102,18 @@ class BasePublisher(object):
             # See if there's a method agnostic handler
             handler = getattr(self, '%s_%s' % (prefix, action), None)
         if handler is None:
-            raise http.Http404
+            return http.NotFound()
         # Do we need to pass any of this?
         return self.execute(handler)
 
     def execute(self, handler, **kwargs):
         '''This allows wrapping calls to handler functions'''
         try:
-            return handler(self.request, action=self.action, object_id=self.object_id, **kwargs)
+            return handler(self.request,
+                action=self.action,
+                object_id=self.object_id,
+                **kwargs
+            )
         except http.BaseHttpResponse as response:
             return response
 
@@ -185,6 +194,8 @@ class Publisher(BasePublisher):
     OFFSET_PARAM = 'offset'
     PAGE_PARAM = 'page'
 
+    response_class = http.HttpResponse
+
     # De/Serialising
     # Which content types will we attempt to parse?
     # The first in the list will be used for responses.
@@ -264,7 +275,7 @@ class Publisher(BasePublisher):
         try:
             page = paginator.page(page_num + 1)
         except EmptyPage:
-            raise http.Http404
+            raise http.NotFound()
         return {
             'meta': {
                 'offset': page.start_index() - 1,
@@ -294,7 +305,7 @@ class Publisher(BasePublisher):
 
     def create_response(self, content, **response_kwargs):
         '''Return a response, serialising the content'''
-        response_class = response_kwargs.pop('response_class', http.HttpResponse)
+        response_class = response_kwargs.pop('response_class', self.response_class)
         response_kwargs.setdefault('content_type', self.CONTENT_TYPES[0])
         return response_class(self.dumps(content), **response_kwargs)
 
@@ -326,5 +337,3 @@ class Publisher(BasePublisher):
         '''Default object GET handler -- get object'''
         obj = self.get_object(object_id)
         return self.render_single_object(obj)
-
-
